@@ -96,6 +96,30 @@ class Sort(object):
             data['files'] = list(reversed(data['files']))
     
 
+class Order(object):
+    """
+    put the files in a particular order
+    """
+    def __init__(self, pattern):
+        if '=' in pattern:
+            key, value = pattern.split('=', 1)
+            assert key == 'file'
+            self.file = value
+        else:
+            self.order = [i.strip() for i in pattern.split(',')]
+    
+    def __call__(self, request, data):
+
+        if self.file:
+            raise NotImplementedError
+
+        files = []
+        file_hash = dict([(i['name'], i) for i in data['files']])
+        for f in self.order:
+            files.append(file_hash.get(f, None))
+        files = [ i for i in files if i is not None ]
+
+
 class FilenameDescription(FormatterBase):
     """
     obtain the description from the filename
@@ -132,6 +156,10 @@ class TitleDescription(FormatterBase):
         for f in data['files']:
             if f['description'] and self.separator in f['description']:
                 title, description = f['description'].split(self.separator, 1)
+                title = title.strip()
+                description = description.strip()
+                if not title:
+                    title = f['name']
                 f['title'] = title
                 f['description'] = description
             else:
